@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -11,9 +11,9 @@ from chaco.api import PlotComponent, AbstractOverlay, OverlayPlotContainer
 from traits.api import Enum, Float, Int, Str, Tuple
 
 from enable.api import ColorTrait
-from enable.example_support import DemoFrame, demo_main
+from enable.examples._example_support import DemoFrame, demo_main
 from enable.tools.api import DragTool
-from kiva.trait_defs.api import KivaFont
+from enable.trait_defs.api import KivaFont
 
 
 class Region(PlotComponent, DragTool):
