@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,7 +8,7 @@
 #
 # Thanks for using Enthought open source!
 from enable.api import OverlayContainer, Slider
-from enable.example_support import demo_main, DemoFrame
+from enable.examples._example_support import demo_main, DemoFrame
 
 
 class Demo(DemoFrame):
