@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,14 +8,13 @@
 #
 # Thanks for using Enthought open source!
 """
-####### NOTE #######
-This is based heavily on matplotlib's font_manager.py SVN rev 8713
-(git commit f8e4c6ce2408044bc89b78b3c72e54deb1999fb5),
-but has been modified quite a bit in the decade since it was copied.
-####################
-
 A module for finding, managing, and using fonts across platforms.
 
+.. note::
+    This is based heavily on matplotlib's font_manager.py SVN rev 8713
+    (git commit f8e4c6ce2408044bc89b78b3c72e54deb1999fb5),
+    but has been modified quite a bit in the decade since it was copied.
+
 The design is based on the `W3C Cascading Style Sheet, Level 1 (CSS1)
 font specification <http://www.w3.org/TR/1998/REC-CSS2-19980512/>`_.
 Future versions may implement the Level 2 or 2.1 specifications.
@@ -76,7 +75,7 @@ class FontManager:
     # Increment this version number whenever the font cache data
     # format or behavior has changed and requires a existing font
     # cache files to be rebuilt.
-    __version__ = 12
+    __version__ = 13
 
     def __init__(self):
         self._version = self.__version__
@@ -121,7 +120,7 @@ class FontManager:
                 data_dir = pkg_resources.resource_filename(
                     "kiva.fonttools", "data"
                 )
-                path = os.path.join(data_dir, " Montserrat-Regular.ttf")
+                path = os.path.join(data_dir, "Montserrat-Regular.ttf")
                 self.default_font["ttf"] = path
 
         self.ttf_db = create_font_database(ttffiles, fontext="ttf")
