@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -8,6 +8,7 @@
 #
 # Thanks for using Enthought open source!
 import ctypes
+import logging
 from math import floor
 import sys
 
@@ -15,11 +16,14 @@ from numpy import array, ndarray
 
 # Local kiva imports
 from kiva.affine import affine_from_values, transform_points
-from kiva.constants import BOLD, BOLD_ITALIC, ITALIC
+from kiva.constants import BOLD, bold_styles, italic_styles
 from kiva.fonttools import Font
 from kiva.gl.gl import CompiledPath, GraphicsContextGL, KivaGLFontType
 
 
+logger = logging.getLogger(__name__)
+
+
 def image_as_array(img):
     """ Adapt an image object into a numpy array.
 
@@ -400,12 +404,8 @@ try:
                         family=kiva_gl_font.family,
                         style=kiva_gl_font.style,
                     )
-                bold = False
-                italic = False
-                if font.style in [BOLD, BOLD_ITALIC] or font.weight == BOLD:
-                    bold = True
-                if font.style in [ITALIC, BOLD_ITALIC]:
-                    italic = True
+                bold = font.is_bold()
+                italic = font.style in italic_styles
                 pyglet_font = load_font(
                     font.findfontname(), font.size, bold, italic
                 )
@@ -442,8 +442,11 @@ try:
         return label
 
 
-except ImportError:
+except ImportError as exc:
     # Pyglet is not available, so we forgo some features
+    logger.exception(
+        "Error importing Pyglet, some features not available in gl backend"
+    )
     ArrayImage = None
     GetFont = None
     GetLabel = None
